Method: Async::IO::SSLSocket#accept

Defined in:
lib/async/io/ssl_socket.rb

#acceptObject

Invokes accept_nonblock on the underlying io. If the operation would block, the current task is paused until the operation can succeed, at which point it’s resumed and the operation is completed.



35
# File 'lib/async/io/ssl_socket.rb', line 35

wrap_blocking_method :accept, :accept_nonblock