Method: Async::IO::Stream#initialize

Defined in:
lib/async/io/stream.rb

#initialize(io, block_size: BLOCK_SIZE, maximum_read_size: MAXIMUM_READ_SIZE, sync: true, deferred: false) ⇒ Stream

Returns a new instance of Stream.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/async/io/stream.rb', line 45

def initialize(io, block_size: BLOCK_SIZE, maximum_read_size: MAXIMUM_READ_SIZE, sync: true, deferred: false)
	@io = io
	@eof = false
	
	@pending = 0
	# This field is ignored, but used to mean, try to buffer packets in a single iteration of the reactor.
	# @deferred = deferred
	
	@writing = Async::Semaphore.new(1)
	
	# We don't want Ruby to do any IO buffering.
	@io.sync = sync
	
	@block_size = block_size
	@maximum_read_size = maximum_read_size
	
	@read_buffer = Buffer.new
	@write_buffer = Buffer.new
	@drain_buffer = Buffer.new
	
	# Used as destination buffer for underlying reads.
	@input_buffer = Buffer.new
end